@@ -59,6 +59,8 @@ classifiers = {
     "Environment :: X11 Applications :: Gnome",
     "Environment :: X11 Applications :: KDE",
     "Environment :: X11 Applications :: Qt",
+    "Framework :: AWS CDK",
+    "Framework :: AWS CDK :: 1",
     "Framework :: AiiDA",
     "Framework :: AsyncIO",
     "Framework :: BEAT",
@@ -726,6 +728,7 @@ classifiers = {
     "Topic :: Text Processing :: Markup",
     "Topic :: Text Processing :: Markup :: HTML",
     "Topic :: Text Processing :: Markup :: LaTeX",
+    "Topic :: Text Processing :: Markup :: Markdown",
     "Topic :: Text Processing :: Markup :: SGML",
     "Topic :: Text Processing :: Markup :: VRML",
     "Topic :: Text Processing :: Markup :: XML",
